@@ -190,7 +190,6 @@ class Icon(object):
         self._setup_thread = threading.Thread(target=setup_handler)
         self._setup_thread.start()
         self._run()
-        self._running = True
 
     def stop(self):
         """Stops the loop handling events for the icon.
@@ -214,7 +213,7 @@ class Icon(object):
         For simple use cases where menu changes are triggered by interaction
         with the menu, this method is not necessary.
         """
-        self._menu_handle = self._create_menu_handle()
+        self._update_menu()
 
     def notify(self, message, title=None):
         """Displays a notification.
@@ -247,6 +246,7 @@ class Icon(object):
         Before the setup method is scheduled to be called, :meth:`update_menu`
         is called.
         """
+        self._running = True
         self.update_menu()
         self.__queue.put(True)
 
@@ -301,8 +301,8 @@ class Icon(object):
         """
         raise NotImplementedError()
 
-    def _create_menu_handle(self):
-        """Creates an opaque menu handle from :attr:`menu`.
+    def _update_menu(self):
+        """Updates the native menu state to mimic :attr:`menu`.
 
         This is a platform dependent implementation.
         """
